/********************************************************************************
** Form generated from reading UI file 'FullScreenWidget.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FULLSCREENWIDGET_H
#define UI_FULLSCREENWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QComboBox>
#include <QtGui/QFrame>
#include <QtGui/QGridLayout>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QScrollArea>
#include <QtGui/QSplitter>
#include <QtGui/QToolButton>
#include <QtGui/QTreeWidget>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "CommandParamsWidget.h"
#include "ImageView.h"

QT_BEGIN_NAMESPACE

class Ui_FullScreenWidget
{
public:
    QHBoxLayout *horizontalLayout;
    ImageView *_imageView;
    QFrame *_rightFrame;
    QVBoxLayout *verticalLayout_2;
    QGridLayout *gridLayout;
    QToolButton *_tbFoldRightPanel;
    QWidget *widget;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label;
    QComboBox *_cbFaves;
    QSplitter *_splitter;
    QTreeWidget *_treePresetsFullScreen;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_2;
    CommandParamsWidget *_commandParamsWidget;

    void setupUi(QWidget *FullScreenWidget)
    {
        if (FullScreenWidget->objectName().isEmpty())
            FullScreenWidget->setObjectName(QString::fromUtf8("FullScreenWidget"));
        FullScreenWidget->resize(850, 590);
        horizontalLayout = new QHBoxLayout(FullScreenWidget);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        _imageView = new ImageView(FullScreenWidget);
        _imageView->setObjectName(QString::fromUtf8("_imageView"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(_imageView->sizePolicy().hasHeightForWidth());
        _imageView->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(_imageView);

        _rightFrame = new QFrame(FullScreenWidget);
        _rightFrame->setObjectName(QString::fromUtf8("_rightFrame"));
        sizePolicy.setHeightForWidth(_rightFrame->sizePolicy().hasHeightForWidth());
        _rightFrame->setSizePolicy(sizePolicy);
        _rightFrame->setFrameShape(QFrame::StyledPanel);
        _rightFrame->setFrameShadow(QFrame::Raised);
        verticalLayout_2 = new QVBoxLayout(_rightFrame);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        gridLayout = new QGridLayout();
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        _tbFoldRightPanel = new QToolButton(_rightFrame);
        _tbFoldRightPanel->setObjectName(QString::fromUtf8("_tbFoldRightPanel"));

        gridLayout->addWidget(_tbFoldRightPanel, 0, 1, 1, 1);

        widget = new QWidget(_rightFrame);
        widget->setObjectName(QString::fromUtf8("widget"));
        QSizePolicy sizePolicy1(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(widget->sizePolicy().hasHeightForWidth());
        widget->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(widget, 0, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        label = new QLabel(_rightFrame);
        label->setObjectName(QString::fromUtf8("label"));
        QSizePolicy sizePolicy2(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy2);

        horizontalLayout_2->addWidget(label);

        _cbFaves = new QComboBox(_rightFrame);
        _cbFaves->setObjectName(QString::fromUtf8("_cbFaves"));

        horizontalLayout_2->addWidget(_cbFaves);


        verticalLayout_2->addLayout(horizontalLayout_2);

        _splitter = new QSplitter(_rightFrame);
        _splitter->setObjectName(QString::fromUtf8("_splitter"));
        _splitter->setOrientation(Qt::Vertical);
        _treePresetsFullScreen = new QTreeWidget(_splitter);
        _treePresetsFullScreen->setObjectName(QString::fromUtf8("_treePresetsFullScreen"));
        _splitter->addWidget(_treePresetsFullScreen);
        scrollArea = new QScrollArea(_splitter);
        scrollArea->setObjectName(QString::fromUtf8("scrollArea"));
        QSizePolicy sizePolicy3(QSizePolicy::Fixed, QSizePolicy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy3);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName(QString::fromUtf8("scrollAreaWidgetContents"));
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 190, 82));
        gridLayout_2 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        _commandParamsWidget = new CommandParamsWidget(scrollAreaWidgetContents);
        _commandParamsWidget->setObjectName(QString::fromUtf8("_commandParamsWidget"));

        gridLayout_2->addWidget(_commandParamsWidget, 0, 0, 1, 1);

        scrollArea->setWidget(scrollAreaWidgetContents);
        _splitter->addWidget(scrollArea);

        verticalLayout_2->addWidget(_splitter);


        horizontalLayout->addWidget(_rightFrame);

        horizontalLayout->setStretch(0, 3);
        horizontalLayout->setStretch(1, 1);

        retranslateUi(FullScreenWidget);

        QMetaObject::connectSlotsByName(FullScreenWidget);
    } // setupUi

    void retranslateUi(QWidget *FullScreenWidget)
    {
        FullScreenWidget->setWindowTitle(QApplication::translate("FullScreenWidget", "Form", 0, QApplication::UnicodeUTF8));
        _tbFoldRightPanel->setText(QApplication::translate("FullScreenWidget", "...", 0, QApplication::UnicodeUTF8));
        label->setText(QApplication::translate("FullScreenWidget", "Faves", 0, QApplication::UnicodeUTF8));
        QTreeWidgetItem *___qtreewidgetitem = _treePresetsFullScreen->headerItem();
        ___qtreewidgetitem->setText(0, QApplication::translate("FullScreenWidget", "Presets", 0, QApplication::UnicodeUTF8));
    } // retranslateUi

};

namespace Ui {
    class FullScreenWidget: public Ui_FullScreenWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FULLSCREENWIDGET_H
