/********************************************************************************
** Form generated from reading UI file 'DialogLicense.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGLICENSE_H
#define UI_DIALOGLICENSE_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QDialog>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QTextEdit>
#include <QtGui/QVBoxLayout>

QT_BEGIN_NAMESPACE

class Ui_DialogLicense
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QTextEdit *_text;
    QHBoxLayout *horizontalLayout;
    QSpacerItem *horizontalSpacer;
    QPushButton *_pkOk;
    QSpacerItem *horizontalSpacer_2;

    void setupUi(QDialog *DialogLicense)
    {
        if (DialogLicense->objectName().isEmpty())
            DialogLicense->setObjectName(QString::fromUtf8("DialogLicense"));
        DialogLicense->resize(591, 376);
        verticalLayout = new QVBoxLayout(DialogLicense);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        label = new QLabel(DialogLicense);
        label->setObjectName(QString::fromUtf8("label"));

        verticalLayout->addWidget(label);

        _text = new QTextEdit(DialogLicense);
        _text->setObjectName(QString::fromUtf8("_text"));
        _text->setReadOnly(true);

        verticalLayout->addWidget(_text);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        _pkOk = new QPushButton(DialogLicense);
        _pkOk->setObjectName(QString::fromUtf8("_pkOk"));

        horizontalLayout->addWidget(_pkOk);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        verticalLayout->addLayout(horizontalLayout);


        retranslateUi(DialogLicense);
        QObject::connect(_pkOk, SIGNAL(pressed()), DialogLicense, SLOT(accept()));

        QMetaObject::connectSlotsByName(DialogLicense);
    } // setupUi

    void retranslateUi(QDialog *DialogLicense)
    {
        DialogLicense->setWindowTitle(QApplication::translate("DialogLicense", "License", 0, QApplication::UnicodeUTF8));
        label->setText(QApplication::translate("DialogLicense", "ZArt license", 0, QApplication::UnicodeUTF8));
        _pkOk->setText(QApplication::translate("DialogLicense", "&Ok", 0, QApplication::UnicodeUTF8));
    } // retranslateUi

};

namespace Ui {
    class DialogLicense: public Ui_DialogLicense {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGLICENSE_H
