/********************************************************************************
** Form generated from reading UI file 'OutputWindow.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OUTPUTWINDOW_H
#define UI_OUTPUTWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QFrame>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QPushButton>
#include <QtGui/QSpacerItem>
#include <QtGui/QToolButton>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "ImageView.h"

QT_BEGIN_NAMESPACE

class Ui_OutputWindow
{
public:
    QVBoxLayout *verticalLayout;
    ImageView *_imageView;
    QFrame *_buttonsFrame;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *_tbFullScreen;
    QSpacerItem *horizontalSpacer;
    QPushButton *_pbClose;

    void setupUi(QWidget *OutputWindow)
    {
        if (OutputWindow->objectName().isEmpty())
            OutputWindow->setObjectName(QString::fromUtf8("OutputWindow"));
        OutputWindow->resize(749, 519);
        verticalLayout = new QVBoxLayout(OutputWindow);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        _imageView = new ImageView(OutputWindow);
        _imageView->setObjectName(QString::fromUtf8("_imageView"));

        verticalLayout->addWidget(_imageView);

        _buttonsFrame = new QFrame(OutputWindow);
        _buttonsFrame->setObjectName(QString::fromUtf8("_buttonsFrame"));
        _buttonsFrame->setFrameShape(QFrame::StyledPanel);
        _buttonsFrame->setFrameShadow(QFrame::Raised);
        horizontalLayout_2 = new QHBoxLayout(_buttonsFrame);
        horizontalLayout_2->setSpacing(3);
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        horizontalLayout_2->setContentsMargins(5, 5, 5, 5);
        _tbFullScreen = new QToolButton(_buttonsFrame);
        _tbFullScreen->setObjectName(QString::fromUtf8("_tbFullScreen"));

        horizontalLayout_2->addWidget(_tbFullScreen);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        _pbClose = new QPushButton(_buttonsFrame);
        _pbClose->setObjectName(QString::fromUtf8("_pbClose"));

        horizontalLayout_2->addWidget(_pbClose);


        verticalLayout->addWidget(_buttonsFrame);

        verticalLayout->setStretch(0, 1);

        retranslateUi(OutputWindow);

        QMetaObject::connectSlotsByName(OutputWindow);
    } // setupUi

    void retranslateUi(QWidget *OutputWindow)
    {
        OutputWindow->setWindowTitle(QApplication::translate("OutputWindow", "Filter output", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        _tbFullScreen->setToolTip(QApplication::translate("OutputWindow", "Show fullscreen", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        _tbFullScreen->setText(QApplication::translate("OutputWindow", "...", 0, QApplication::UnicodeUTF8));
        _pbClose->setText(QApplication::translate("OutputWindow", "Close", 0, QApplication::UnicodeUTF8));
    } // retranslateUi

};

namespace Ui {
    class OutputWindow: public Ui_OutputWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OUTPUTWINDOW_H
