/********************************************************************************
** Form generated from reading UI file 'MainWindow.ui'
**
** Created by: Qt User Interface Compiler version 4.8.7
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAINWINDOW_H
#define UI_MAINWINDOW_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtGui/QApplication>
#include <QtGui/QButtonGroup>
#include <QtGui/QCheckBox>
#include <QtGui/QComboBox>
#include <QtGui/QFrame>
#include <QtGui/QGridLayout>
#include <QtGui/QHBoxLayout>
#include <QtGui/QHeaderView>
#include <QtGui/QLabel>
#include <QtGui/QMainWindow>
#include <QtGui/QMenuBar>
#include <QtGui/QPushButton>
#include <QtGui/QScrollArea>
#include <QtGui/QSlider>
#include <QtGui/QSpacerItem>
#include <QtGui/QSplitter>
#include <QtGui/QStatusBar>
#include <QtGui/QTabWidget>
#include <QtGui/QToolButton>
#include <QtGui/QTreeWidget>
#include <QtGui/QVBoxLayout>
#include <QtGui/QWidget>
#include "CommandParamsWidget.h"
#include "ImageView.h"
#include "include/CommandEditor.h"

QT_BEGIN_NAMESPACE

class Ui_MainWindow
{
public:
    QWidget *centralwidget;
    QHBoxLayout *horizontalLayout_3;
    QSplitter *_verticalSplitter;
    QSplitter *_leftSplitter;
    QFrame *_frameImageView;
    QGridLayout *gridLayout;
    ImageView *_imageView;
    QWidget *layoutWidget2;
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    CommandEditor *_commandEditor;
    QHBoxLayout *horizontalLayout_4;
    QSpacerItem *horizontalSpacer_2;
    QPushButton *_pbApply;
    QSpacerItem *horizontalSpacer_3;
    QWidget *_rightPanel;
    QVBoxLayout *verticalLayout_5;
    QSplitter *_rightPanelSplitter;
    QWidget *layoutWidget1;
    QVBoxLayout *verticalLayout_4;
    QTreeWidget *_treeGPresets;
    QHBoxLayout *horizontalLayout;
    QLabel *label_14;
    QToolButton *_tbAddFave;
    QToolButton *_tbRemoveFave;
    QToolButton *_tbRenameFave;
    QComboBox *_cbFaves;
    QWidget *layoutWidget3;
    QVBoxLayout *verticalLayout_2;
    QFrame *line;
    QGridLayout *gridLayout_2;
    QComboBox *_cbPreviewMode;
    QLabel *label_4;
    QLabel *label;
    QComboBox *_comboSource;
    QFrame *line_4;
    QTabWidget *_tabParams;
    QWidget *tabSourceParams;
    QGridLayout *gridLayout_4;
    QWidget *_imageParamsWidget;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_3;
    QSlider *_sliderImageFPS;
    QLabel *label_5;
    QPushButton *_pbOpenImageFile;
    QWidget *_videoParamsWidget;
    QGridLayout *gridLayout_6;
    QPushButton *_pbOpenVideoFile;
    QCheckBox *_cbVideoFileLoop;
    QLabel *label_7;
    QLabel *label_11;
    QSlider *_sliderVideoFPS;
    QLabel *label_8;
    QLabel *_labelVideoSkipFrames;
    QLabel *label_12;
    QSlider *_sliderVideoSkipFrames;
    QLabel *label_6;
    QSpacerItem *verticalSpacer_2;
    QWidget *_webcamParamsWidget;
    QGridLayout *gridLayout_3;
    QLabel *label_13;
    QLabel *label_10;
    QSlider *_sliderWebcamSkipFrames;
    QLabel *_labelInputWebcam;
    QComboBox *_comboWebcam;
    QLabel *_labelWebcamSkipFrames;
    QLabel *label_9;
    QComboBox *_comboCamResolution;
    QToolButton *_tbCamResolutionsRefresh;
    QWidget *tabCommandParams;
    QGridLayout *gridLayout_7;
    QScrollArea *_commandParamsScrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_5;
    CommandParamsWidget *_commandParamsWidget;
    QToolButton *_tbPlay;
    QFrame *line_2;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *_tbZoomOriginal;
    QToolButton *_tbZoomFit;
    QSpacerItem *horizontalSpacer;
    QToolButton *_tbCamera;
    QMenuBar *menubar;
    QStatusBar *statusbar;

    void setupUi(QMainWindow *MainWindow)
    {
        if (MainWindow->objectName().isEmpty())
            MainWindow->setObjectName(QString::fromUtf8("MainWindow"));
        MainWindow->resize(985, 830);
        centralwidget = new QWidget(MainWindow);
        centralwidget->setObjectName(QString::fromUtf8("centralwidget"));
        horizontalLayout_3 = new QHBoxLayout(centralwidget);
        horizontalLayout_3->setObjectName(QString::fromUtf8("horizontalLayout_3"));
        _verticalSplitter = new QSplitter(centralwidget);
        _verticalSplitter->setObjectName(QString::fromUtf8("_verticalSplitter"));
        _verticalSplitter->setOrientation(Qt::Horizontal);
        _leftSplitter = new QSplitter(_verticalSplitter);
        _leftSplitter->setObjectName(QString::fromUtf8("_leftSplitter"));
        QSizePolicy sizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(_leftSplitter->sizePolicy().hasHeightForWidth());
        _leftSplitter->setSizePolicy(sizePolicy);
        _leftSplitter->setOrientation(Qt::Vertical);
        _frameImageView = new QFrame(_leftSplitter);
        _frameImageView->setObjectName(QString::fromUtf8("_frameImageView"));
        QSizePolicy sizePolicy1(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(_frameImageView->sizePolicy().hasHeightForWidth());
        _frameImageView->setSizePolicy(sizePolicy1);
        _frameImageView->setMinimumSize(QSize(0, 200));
        _frameImageView->setFrameShape(QFrame::StyledPanel);
        _frameImageView->setFrameShadow(QFrame::Raised);
        gridLayout = new QGridLayout(_frameImageView);
        gridLayout->setObjectName(QString::fromUtf8("gridLayout"));
        gridLayout->setSizeConstraint(QLayout::SetDefaultConstraint);
        _imageView = new ImageView(_frameImageView);
        _imageView->setObjectName(QString::fromUtf8("_imageView"));
        QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(_imageView->sizePolicy().hasHeightForWidth());
        _imageView->setSizePolicy(sizePolicy2);
        _imageView->setMinimumSize(QSize(0, 0));

        gridLayout->addWidget(_imageView, 0, 0, 1, 1);

        _leftSplitter->addWidget(_frameImageView);
        layoutWidget2 = new QWidget(_leftSplitter);
        layoutWidget2->setObjectName(QString::fromUtf8("layoutWidget2"));
        verticalLayout = new QVBoxLayout(layoutWidget2);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(layoutWidget2);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        QSizePolicy sizePolicy3(QSizePolicy::Preferred, QSizePolicy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(label_2->sizePolicy().hasHeightForWidth());
        label_2->setSizePolicy(sizePolicy3);

        verticalLayout->addWidget(label_2);

        _commandEditor = new CommandEditor(layoutWidget2);
        _commandEditor->setObjectName(QString::fromUtf8("_commandEditor"));
        QSizePolicy sizePolicy4(QSizePolicy::Expanding, QSizePolicy::Minimum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(_commandEditor->sizePolicy().hasHeightForWidth());
        _commandEditor->setSizePolicy(sizePolicy4);
        _commandEditor->setMinimumSize(QSize(0, 100));

        verticalLayout->addWidget(_commandEditor);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName(QString::fromUtf8("horizontalLayout_4"));
        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_2);

        _pbApply = new QPushButton(layoutWidget2);
        _pbApply->setObjectName(QString::fromUtf8("_pbApply"));

        horizontalLayout_4->addWidget(_pbApply);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        verticalLayout->addLayout(horizontalLayout_4);

        verticalLayout->setStretch(0, 1);
        verticalLayout->setStretch(1, 8);
        verticalLayout->setStretch(2, 1);
        _leftSplitter->addWidget(layoutWidget2);
        _verticalSplitter->addWidget(_leftSplitter);
        _rightPanel = new QWidget(_verticalSplitter);
        _rightPanel->setObjectName(QString::fromUtf8("_rightPanel"));
        QSizePolicy sizePolicy5(QSizePolicy::Fixed, QSizePolicy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(_rightPanel->sizePolicy().hasHeightForWidth());
        _rightPanel->setSizePolicy(sizePolicy5);
        verticalLayout_5 = new QVBoxLayout(_rightPanel);
        verticalLayout_5->setObjectName(QString::fromUtf8("verticalLayout_5"));
        _rightPanelSplitter = new QSplitter(_rightPanel);
        _rightPanelSplitter->setObjectName(QString::fromUtf8("_rightPanelSplitter"));
        _rightPanelSplitter->setOrientation(Qt::Vertical);
        layoutWidget1 = new QWidget(_rightPanelSplitter);
        layoutWidget1->setObjectName(QString::fromUtf8("layoutWidget1"));
        verticalLayout_4 = new QVBoxLayout(layoutWidget1);
        verticalLayout_4->setObjectName(QString::fromUtf8("verticalLayout_4"));
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        _treeGPresets = new QTreeWidget(layoutWidget1);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("Presets"));
        _treeGPresets->setHeaderItem(__qtreewidgetitem);
        _treeGPresets->setObjectName(QString::fromUtf8("_treeGPresets"));
        QSizePolicy sizePolicy6(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(_treeGPresets->sizePolicy().hasHeightForWidth());
        _treeGPresets->setSizePolicy(sizePolicy6);

        verticalLayout_4->addWidget(_treeGPresets);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        label_14 = new QLabel(layoutWidget1);
        label_14->setObjectName(QString::fromUtf8("label_14"));
        sizePolicy5.setHeightForWidth(label_14->sizePolicy().hasHeightForWidth());
        label_14->setSizePolicy(sizePolicy5);

        horizontalLayout->addWidget(label_14);

        _tbAddFave = new QToolButton(layoutWidget1);
        _tbAddFave->setObjectName(QString::fromUtf8("_tbAddFave"));

        horizontalLayout->addWidget(_tbAddFave);

        _tbRemoveFave = new QToolButton(layoutWidget1);
        _tbRemoveFave->setObjectName(QString::fromUtf8("_tbRemoveFave"));

        horizontalLayout->addWidget(_tbRemoveFave);

        _tbRenameFave = new QToolButton(layoutWidget1);
        _tbRenameFave->setObjectName(QString::fromUtf8("_tbRenameFave"));

        horizontalLayout->addWidget(_tbRenameFave);

        _cbFaves = new QComboBox(layoutWidget1);
        _cbFaves->setObjectName(QString::fromUtf8("_cbFaves"));

        horizontalLayout->addWidget(_cbFaves);


        verticalLayout_4->addLayout(horizontalLayout);

        _rightPanelSplitter->addWidget(layoutWidget1);
        layoutWidget3 = new QWidget(_rightPanelSplitter);
        layoutWidget3->setObjectName(QString::fromUtf8("layoutWidget3"));
        verticalLayout_2 = new QVBoxLayout(layoutWidget3);
        verticalLayout_2->setObjectName(QString::fromUtf8("verticalLayout_2"));
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        line = new QFrame(layoutWidget3);
        line->setObjectName(QString::fromUtf8("line"));
        line->setFrameShape(QFrame::HLine);
        line->setFrameShadow(QFrame::Sunken);

        verticalLayout_2->addWidget(line);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName(QString::fromUtf8("gridLayout_2"));
        _cbPreviewMode = new QComboBox(layoutWidget3);
        _cbPreviewMode->setObjectName(QString::fromUtf8("_cbPreviewMode"));
        sizePolicy3.setHeightForWidth(_cbPreviewMode->sizePolicy().hasHeightForWidth());
        _cbPreviewMode->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(_cbPreviewMode, 0, 1, 1, 1);

        label_4 = new QLabel(layoutWidget3);
        label_4->setObjectName(QString::fromUtf8("label_4"));

        gridLayout_2->addWidget(label_4, 1, 0, 1, 1);

        label = new QLabel(layoutWidget3);
        label->setObjectName(QString::fromUtf8("label"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        _comboSource = new QComboBox(layoutWidget3);
        _comboSource->setObjectName(QString::fromUtf8("_comboSource"));

        gridLayout_2->addWidget(_comboSource, 1, 1, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        line_4 = new QFrame(layoutWidget3);
        line_4->setObjectName(QString::fromUtf8("line_4"));
        line_4->setFrameShape(QFrame::HLine);
        line_4->setFrameShadow(QFrame::Sunken);

        verticalLayout_2->addWidget(line_4);

        _tabParams = new QTabWidget(layoutWidget3);
        _tabParams->setObjectName(QString::fromUtf8("_tabParams"));
        QSizePolicy sizePolicy7(QSizePolicy::Expanding, QSizePolicy::MinimumExpanding);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(_tabParams->sizePolicy().hasHeightForWidth());
        _tabParams->setSizePolicy(sizePolicy7);
        _tabParams->setTabShape(QTabWidget::Rounded);
        _tabParams->setElideMode(Qt::ElideNone);
        tabSourceParams = new QWidget();
        tabSourceParams->setObjectName(QString::fromUtf8("tabSourceParams"));
        gridLayout_4 = new QGridLayout(tabSourceParams);
        gridLayout_4->setObjectName(QString::fromUtf8("gridLayout_4"));
        _imageParamsWidget = new QWidget(tabSourceParams);
        _imageParamsWidget->setObjectName(QString::fromUtf8("_imageParamsWidget"));
        verticalLayout_3 = new QVBoxLayout(_imageParamsWidget);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName(QString::fromUtf8("horizontalLayout_5"));
        label_3 = new QLabel(_imageParamsWidget);
        label_3->setObjectName(QString::fromUtf8("label_3"));

        horizontalLayout_5->addWidget(label_3);

        _sliderImageFPS = new QSlider(_imageParamsWidget);
        _sliderImageFPS->setObjectName(QString::fromUtf8("_sliderImageFPS"));
        _sliderImageFPS->setMinimum(0);
        _sliderImageFPS->setMaximum(30);
        _sliderImageFPS->setOrientation(Qt::Horizontal);

        horizontalLayout_5->addWidget(_sliderImageFPS);

        label_5 = new QLabel(_imageParamsWidget);
        label_5->setObjectName(QString::fromUtf8("label_5"));

        horizontalLayout_5->addWidget(label_5);


        verticalLayout_3->addLayout(horizontalLayout_5);

        _pbOpenImageFile = new QPushButton(_imageParamsWidget);
        _pbOpenImageFile->setObjectName(QString::fromUtf8("_pbOpenImageFile"));

        verticalLayout_3->addWidget(_pbOpenImageFile);


        gridLayout_4->addWidget(_imageParamsWidget, 2, 0, 1, 1);

        _videoParamsWidget = new QWidget(tabSourceParams);
        _videoParamsWidget->setObjectName(QString::fromUtf8("_videoParamsWidget"));
        gridLayout_6 = new QGridLayout(_videoParamsWidget);
        gridLayout_6->setObjectName(QString::fromUtf8("gridLayout_6"));
        _pbOpenVideoFile = new QPushButton(_videoParamsWidget);
        _pbOpenVideoFile->setObjectName(QString::fromUtf8("_pbOpenVideoFile"));
        QSizePolicy sizePolicy8(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(_pbOpenVideoFile->sizePolicy().hasHeightForWidth());
        _pbOpenVideoFile->setSizePolicy(sizePolicy8);

        gridLayout_6->addWidget(_pbOpenVideoFile, 0, 0, 1, 3);

        _cbVideoFileLoop = new QCheckBox(_videoParamsWidget);
        _cbVideoFileLoop->setObjectName(QString::fromUtf8("_cbVideoFileLoop"));
        sizePolicy3.setHeightForWidth(_cbVideoFileLoop->sizePolicy().hasHeightForWidth());
        _cbVideoFileLoop->setSizePolicy(sizePolicy3);

        gridLayout_6->addWidget(_cbVideoFileLoop, 0, 3, 1, 2);

        label_7 = new QLabel(_videoParamsWidget);
        label_7->setObjectName(QString::fromUtf8("label_7"));

        gridLayout_6->addWidget(label_7, 1, 0, 1, 1);

        label_11 = new QLabel(_videoParamsWidget);
        label_11->setObjectName(QString::fromUtf8("label_11"));
        sizePolicy5.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy5);

        gridLayout_6->addWidget(label_11, 1, 1, 1, 1);

        _sliderVideoFPS = new QSlider(_videoParamsWidget);
        _sliderVideoFPS->setObjectName(QString::fromUtf8("_sliderVideoFPS"));
        _sliderVideoFPS->setMinimum(5);
        _sliderVideoFPS->setMaximum(30);
        _sliderVideoFPS->setOrientation(Qt::Horizontal);

        gridLayout_6->addWidget(_sliderVideoFPS, 1, 2, 1, 2);

        label_8 = new QLabel(_videoParamsWidget);
        label_8->setObjectName(QString::fromUtf8("label_8"));
        sizePolicy5.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy5);

        gridLayout_6->addWidget(label_8, 1, 4, 1, 1);

        _labelVideoSkipFrames = new QLabel(_videoParamsWidget);
        _labelVideoSkipFrames->setObjectName(QString::fromUtf8("_labelVideoSkipFrames"));

        gridLayout_6->addWidget(_labelVideoSkipFrames, 2, 0, 1, 1);

        label_12 = new QLabel(_videoParamsWidget);
        label_12->setObjectName(QString::fromUtf8("label_12"));
        sizePolicy5.setHeightForWidth(label_12->sizePolicy().hasHeightForWidth());
        label_12->setSizePolicy(sizePolicy5);

        gridLayout_6->addWidget(label_12, 2, 1, 1, 1);

        _sliderVideoSkipFrames = new QSlider(_videoParamsWidget);
        _sliderVideoSkipFrames->setObjectName(QString::fromUtf8("_sliderVideoSkipFrames"));
        _sliderVideoSkipFrames->setOrientation(Qt::Horizontal);

        gridLayout_6->addWidget(_sliderVideoSkipFrames, 2, 2, 1, 2);

        label_6 = new QLabel(_videoParamsWidget);
        label_6->setObjectName(QString::fromUtf8("label_6"));
        sizePolicy2.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy2);

        gridLayout_6->addWidget(label_6, 2, 4, 1, 1);


        gridLayout_4->addWidget(_videoParamsWidget, 3, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 10, QSizePolicy::Minimum, QSizePolicy::Expanding);

        gridLayout_4->addItem(verticalSpacer_2, 4, 0, 1, 1);

        _webcamParamsWidget = new QWidget(tabSourceParams);
        _webcamParamsWidget->setObjectName(QString::fromUtf8("_webcamParamsWidget"));
        gridLayout_3 = new QGridLayout(_webcamParamsWidget);
        gridLayout_3->setObjectName(QString::fromUtf8("gridLayout_3"));
        gridLayout_3->setContentsMargins(9, 9, 9, 9);
        label_13 = new QLabel(_webcamParamsWidget);
        label_13->setObjectName(QString::fromUtf8("label_13"));

        gridLayout_3->addWidget(label_13, 1, 0, 1, 1);

        label_10 = new QLabel(_webcamParamsWidget);
        label_10->setObjectName(QString::fromUtf8("label_10"));

        gridLayout_3->addWidget(label_10, 2, 1, 1, 1);

        _sliderWebcamSkipFrames = new QSlider(_webcamParamsWidget);
        _sliderWebcamSkipFrames->setObjectName(QString::fromUtf8("_sliderWebcamSkipFrames"));
        QSizePolicy sizePolicy9(QSizePolicy::Expanding, QSizePolicy::Fixed);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(_sliderWebcamSkipFrames->sizePolicy().hasHeightForWidth());
        _sliderWebcamSkipFrames->setSizePolicy(sizePolicy9);
        _sliderWebcamSkipFrames->setMaximum(25);
        _sliderWebcamSkipFrames->setPageStep(1);
        _sliderWebcamSkipFrames->setOrientation(Qt::Horizontal);

        gridLayout_3->addWidget(_sliderWebcamSkipFrames, 2, 2, 1, 1);

        _labelInputWebcam = new QLabel(_webcamParamsWidget);
        _labelInputWebcam->setObjectName(QString::fromUtf8("_labelInputWebcam"));

        gridLayout_3->addWidget(_labelInputWebcam, 0, 0, 1, 1);

        _comboWebcam = new QComboBox(_webcamParamsWidget);
        _comboWebcam->setObjectName(QString::fromUtf8("_comboWebcam"));

        gridLayout_3->addWidget(_comboWebcam, 0, 1, 1, 3);

        _labelWebcamSkipFrames = new QLabel(_webcamParamsWidget);
        _labelWebcamSkipFrames->setObjectName(QString::fromUtf8("_labelWebcamSkipFrames"));

        gridLayout_3->addWidget(_labelWebcamSkipFrames, 2, 0, 1, 1);

        label_9 = new QLabel(_webcamParamsWidget);
        label_9->setObjectName(QString::fromUtf8("label_9"));

        gridLayout_3->addWidget(label_9, 2, 3, 1, 1);

        _comboCamResolution = new QComboBox(_webcamParamsWidget);
        _comboCamResolution->setObjectName(QString::fromUtf8("_comboCamResolution"));

        gridLayout_3->addWidget(_comboCamResolution, 1, 1, 1, 2);

        _tbCamResolutionsRefresh = new QToolButton(_webcamParamsWidget);
        _tbCamResolutionsRefresh->setObjectName(QString::fromUtf8("_tbCamResolutionsRefresh"));

        gridLayout_3->addWidget(_tbCamResolutionsRefresh, 1, 3, 1, 1);


        gridLayout_4->addWidget(_webcamParamsWidget, 1, 0, 1, 1);

        _tabParams->addTab(tabSourceParams, QString());
        tabCommandParams = new QWidget();
        tabCommandParams->setObjectName(QString::fromUtf8("tabCommandParams"));
        gridLayout_7 = new QGridLayout(tabCommandParams);
        gridLayout_7->setObjectName(QString::fromUtf8("gridLayout_7"));
        _commandParamsScrollArea = new QScrollArea(tabCommandParams);
        _commandParamsScrollArea->setObjectName(QString::fromUtf8("_commandParamsScrollArea"));
        _commandParamsScrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName(QString::fromUtf8("scrollAreaWidgetContents"));
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 453, 291));
        gridLayout_5 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_5->setObjectName(QString::fromUtf8("gridLayout_5"));
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        _commandParamsWidget = new CommandParamsWidget(scrollAreaWidgetContents);
        _commandParamsWidget->setObjectName(QString::fromUtf8("_commandParamsWidget"));

        gridLayout_5->addWidget(_commandParamsWidget, 0, 0, 1, 1);

        _commandParamsScrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout_7->addWidget(_commandParamsScrollArea, 0, 0, 1, 1);

        _tabParams->addTab(tabCommandParams, QString());

        verticalLayout_2->addWidget(_tabParams);

        _tbPlay = new QToolButton(layoutWidget3);
        _tbPlay->setObjectName(QString::fromUtf8("_tbPlay"));
        QSizePolicy sizePolicy10(QSizePolicy::Minimum, QSizePolicy::Fixed);
        sizePolicy10.setHorizontalStretch(0);
        sizePolicy10.setVerticalStretch(0);
        sizePolicy10.setHeightForWidth(_tbPlay->sizePolicy().hasHeightForWidth());
        _tbPlay->setSizePolicy(sizePolicy10);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/media-playback-start.png"), QSize(), QIcon::Normal, QIcon::Off);
        _tbPlay->setIcon(icon);
        _tbPlay->setIconSize(QSize(24, 24));
        _tbPlay->setCheckable(false);

        verticalLayout_2->addWidget(_tbPlay);

        line_2 = new QFrame(layoutWidget3);
        line_2->setObjectName(QString::fromUtf8("line_2"));
        line_2->setFrameShape(QFrame::HLine);
        line_2->setFrameShadow(QFrame::Sunken);

        verticalLayout_2->addWidget(line_2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName(QString::fromUtf8("horizontalLayout_2"));
        _tbZoomOriginal = new QToolButton(layoutWidget3);
        _tbZoomOriginal->setObjectName(QString::fromUtf8("_tbZoomOriginal"));
        sizePolicy2.setHeightForWidth(_tbZoomOriginal->sizePolicy().hasHeightForWidth());
        _tbZoomOriginal->setSizePolicy(sizePolicy2);
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/images/zoom-original.png"), QSize(), QIcon::Normal, QIcon::Off);
        _tbZoomOriginal->setIcon(icon1);

        horizontalLayout_2->addWidget(_tbZoomOriginal);

        _tbZoomFit = new QToolButton(layoutWidget3);
        _tbZoomFit->setObjectName(QString::fromUtf8("_tbZoomFit"));
        sizePolicy2.setHeightForWidth(_tbZoomFit->sizePolicy().hasHeightForWidth());
        _tbZoomFit->setSizePolicy(sizePolicy2);
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/images/zoom-fit-best.png"), QSize(), QIcon::Normal, QIcon::Off);
        _tbZoomFit->setIcon(icon2);
        _tbZoomFit->setIconSize(QSize(24, 24));

        horizontalLayout_2->addWidget(_tbZoomFit);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Expanding, QSizePolicy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        _tbCamera = new QToolButton(layoutWidget3);
        _tbCamera->setObjectName(QString::fromUtf8("_tbCamera"));
        sizePolicy2.setHeightForWidth(_tbCamera->sizePolicy().hasHeightForWidth());
        _tbCamera->setSizePolicy(sizePolicy2);
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/images/camera.png"), QSize(), QIcon::Normal, QIcon::Off);
        _tbCamera->setIcon(icon3);

        horizontalLayout_2->addWidget(_tbCamera);


        verticalLayout_2->addLayout(horizontalLayout_2);

        _rightPanelSplitter->addWidget(layoutWidget3);

        verticalLayout_5->addWidget(_rightPanelSplitter);

        _verticalSplitter->addWidget(_rightPanel);

        horizontalLayout_3->addWidget(_verticalSplitter);

        MainWindow->setCentralWidget(centralwidget);
        menubar = new QMenuBar(MainWindow);
        menubar->setObjectName(QString::fromUtf8("menubar"));
        menubar->setGeometry(QRect(0, 0, 985, 22));
        MainWindow->setMenuBar(menubar);
        statusbar = new QStatusBar(MainWindow);
        statusbar->setObjectName(QString::fromUtf8("statusbar"));
        MainWindow->setStatusBar(statusbar);

        retranslateUi(MainWindow);

        _tabParams->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(MainWindow);
    } // setupUi

    void retranslateUi(QMainWindow *MainWindow)
    {
        MainWindow->setWindowTitle(QApplication::translate("MainWindow", "MainWindow", 0, QApplication::UnicodeUTF8));
        label_2->setText(QApplication::translate("MainWindow", "G'MIC program", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        _pbApply->setToolTip(QApplication::translate("MainWindow", "Apply script modifications (Ctrl+Return)", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        _pbApply->setText(QApplication::translate("MainWindow", "Apply", 0, QApplication::UnicodeUTF8));
        label_14->setText(QApplication::translate("MainWindow", "Faves", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        _tbAddFave->setToolTip(QApplication::translate("MainWindow", "Add filter to faves", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        _tbRemoveFave->setToolTip(QApplication::translate("MainWindow", "Remove fave", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
#ifndef QT_NO_TOOLTIP
        _tbRenameFave->setToolTip(QApplication::translate("MainWindow", "Rename fave", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        label_4->setText(QApplication::translate("MainWindow", "Source", 0, QApplication::UnicodeUTF8));
        label->setText(QApplication::translate("MainWindow", "Preview mode", 0, QApplication::UnicodeUTF8));
        label_3->setText(QApplication::translate("MainWindow", "FPS  0", 0, QApplication::UnicodeUTF8));
        label_5->setText(QApplication::translate("MainWindow", "30", 0, QApplication::UnicodeUTF8));
        _pbOpenImageFile->setText(QApplication::translate("MainWindow", "Open...", 0, QApplication::UnicodeUTF8));
        _pbOpenVideoFile->setText(QApplication::translate("MainWindow", "Open...", 0, QApplication::UnicodeUTF8));
        _cbVideoFileLoop->setText(QApplication::translate("MainWindow", "Loop", 0, QApplication::UnicodeUTF8));
        label_7->setText(QApplication::translate("MainWindow", "FPS", 0, QApplication::UnicodeUTF8));
        label_11->setText(QApplication::translate("MainWindow", "5", 0, QApplication::UnicodeUTF8));
        label_8->setText(QApplication::translate("MainWindow", "30", 0, QApplication::UnicodeUTF8));
        _labelVideoSkipFrames->setText(QApplication::translate("MainWindow", "Frame skip", 0, QApplication::UnicodeUTF8));
        label_12->setText(QApplication::translate("MainWindow", "0", 0, QApplication::UnicodeUTF8));
        label_6->setText(QApplication::translate("MainWindow", "10", 0, QApplication::UnicodeUTF8));
        label_13->setText(QApplication::translate("MainWindow", "Resolution", 0, QApplication::UnicodeUTF8));
        label_10->setText(QApplication::translate("MainWindow", "0", 0, QApplication::UnicodeUTF8));
        _labelInputWebcam->setText(QApplication::translate("MainWindow", "Input", 0, QApplication::UnicodeUTF8));
        _labelWebcamSkipFrames->setText(QApplication::translate("MainWindow", "Frame skip", 0, QApplication::UnicodeUTF8));
        label_9->setText(QApplication::translate("MainWindow", "10", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        _tbCamResolutionsRefresh->setToolTip(QApplication::translate("MainWindow", "Refresh resolutions", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        _tbCamResolutionsRefresh->setText(QApplication::translate("MainWindow", "U", 0, QApplication::UnicodeUTF8));
        _tabParams->setTabText(_tabParams->indexOf(tabSourceParams), QApplication::translate("MainWindow", "Source params", 0, QApplication::UnicodeUTF8));
        _tabParams->setTabText(_tabParams->indexOf(tabCommandParams), QApplication::translate("MainWindow", "Filter params", 0, QApplication::UnicodeUTF8));
        _tbPlay->setText(QApplication::translate("MainWindow", "...", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        _tbZoomOriginal->setToolTip(QApplication::translate("MainWindow", "Set zoom factor to 1:1", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        _tbZoomOriginal->setText(QApplication::translate("MainWindow", "...", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        _tbZoomFit->setToolTip(QApplication::translate("MainWindow", "Best fit zoom", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        _tbZoomFit->setText(QApplication::translate("MainWindow", "...", 0, QApplication::UnicodeUTF8));
#ifndef QT_NO_TOOLTIP
        _tbCamera->setToolTip(QApplication::translate("MainWindow", "Take a snapshot", 0, QApplication::UnicodeUTF8));
#endif // QT_NO_TOOLTIP
        _tbCamera->setText(QApplication::translate("MainWindow", "...", 0, QApplication::UnicodeUTF8));
    } // retranslateUi

};

namespace Ui {
    class MainWindow: public Ui_MainWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAINWINDOW_H
