/****************************************************************************
** Meta object code from reading C++ file 'MainWindow.h'
**
** Created by: The Qt Meta Object Compiler version 63 (Qt 4.8.7)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../include/MainWindow.h"
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'MainWindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 63
#error "This file was generated using the moc from 4.8.7. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
static const uint qt_meta_data_MainWindow[] = {

 // content:
       6,       // revision
       0,       // classname
       0,    0, // classinfo
      44,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: signature, parameters, type, tag, flags
      12,   11,   11,   11, 0x0a,
      19,   11,   11,   11, 0x0a,
      26,   11,   11,   11, 0x0a,
      45,   11,   11,   11, 0x0a,
      61,   11,   11,   11, 0x0a,
      80,   11,   11,   11, 0x0a,
     110,   98,   11,   11, 0x0a,
     146,   11,   11,   11, 0x0a,
     180,   11,   11,   11, 0x0a,
     191,   11,   11,   11, 0x0a,
     199,   11,   11,   11, 0x0a,
     209,   11,   11,   11, 0x0a,
     221,   11,   11,   11, 0x0a,
     246,   11,   11,   11, 0x0a,
     270,   11,   11,   11, 0x0a,
     287,   11,   11,   11, 0x0a,
     304,   11,   11,   11, 0x0a,
     328,   11,   11,   11, 0x2a,
     345,   11,   11,   11, 0x0a,
     369,  363,   11,   11, 0x0a,
     397,  395,   11,   11, 0x0a,
     433,   11,   11,   11, 0x0a,
     459,   11,   11,   11, 0x0a,
     477,  363,   11,   11, 0x0a,
     503,   11,   11,   11, 0x0a,
     522,   11,   11,   11, 0x0a,
     548,   11,   11,   11, 0x0a,
     566,   11,   11,   11, 0x0a,
     584,   11,   11,   11, 0x0a,
     604,   11,   11,   11, 0x0a,
     626,   11,   11,   11, 0x0a,
     659,   11,   11,   11, 0x0a,
     684,   11,   11,   11, 0x0a,
     713,   11,   11,   11, 0x0a,
     752,   11,   11,   11, 0x0a,
     775,   11,   11,   11, 0x0a,
     804,   11,   11,   11, 0x0a,
     842,  822,   11,   11, 0x0a,
     880,   11,   11,   11, 0x0a,
     901,   11,   11,   11, 0x0a,
     925,   11,   11,   11, 0x0a,
     937,   11,   11,   11, 0x0a,
     952,   11,   11,   11, 0x0a,
     972,   11,   11,   11, 0x0a,

       0        // eod
};

static const char qt_meta_stringdata_MainWindow[] = {
    "MainWindow\0\0play()\0stop()\0onImageAvailable()\0"
    "onEndOfSource()\0onPlayAction(bool)\0"
    "commandModified()\0item,column\0"
    "presetClicked(QTreeWidgetItem*,int)\0"
    "imageViewMouseEvent(QMouseEvent*)\0"
    "snapshot()\0about()\0license()\0visitGMIC()\0"
    "setWebcamSkipFrames(int)\0"
    "setVideoSkipFrames(int)\0setImageFPS(int)\0"
    "setVideoFPS(int)\0setPresetsFile(QString)\0"
    "setPresetsFile()\0savePresetsFile()\0"
    "index\0onWebcamComboChanged(int)\0i\0"
    "onWebcamResolutionComboChanged(int)\0"
    "onUseBuiltinPresets(bool)\0onReloadPresets()\0"
    "onPreviewModeChanged(int)\0onRightPanel(bool)\0"
    "onComboSourceChanged(int)\0onOpenImageFile()\0"
    "onOpenVideoFile()\0updateWindowTitle()\0"
    "onVideoFileLoop(bool)\0"
    "changePlayButtonAppearence(bool)\0"
    "onFilterThreadFinished()\0"
    "onCommandParametersChanged()\0"
    "onCommandParametersChangedFullScreen()\0"
    "toggleFullScreenMode()\0"
    "onRefreshCameraResolutions()\0"
    "onDetectCameras()\0camList,firstUnused\0"
    "initGUIFromCameraList(QList<int>,int)\0"
    "onOutputWindow(bool)\0onOutputWindowClosing()\0"
    "onAddFave()\0onRemoveFave()\0"
    "onFaveSelected(int)\0onRenameFave()\0"
};

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Q_ASSERT(staticMetaObject.cast(_o));
        MainWindow *_t = static_cast<MainWindow *>(_o);
        switch (_id) {
        case 0: _t->play(); break;
        case 1: _t->stop(); break;
        case 2: _t->onImageAvailable(); break;
        case 3: _t->onEndOfSource(); break;
        case 4: _t->onPlayAction((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 5: _t->commandModified(); break;
        case 6: _t->presetClicked((*reinterpret_cast< QTreeWidgetItem*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 7: _t->imageViewMouseEvent((*reinterpret_cast< QMouseEvent*(*)>(_a[1]))); break;
        case 8: _t->snapshot(); break;
        case 9: _t->about(); break;
        case 10: _t->license(); break;
        case 11: _t->visitGMIC(); break;
        case 12: _t->setWebcamSkipFrames((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 13: _t->setVideoSkipFrames((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 14: _t->setImageFPS((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->setVideoFPS((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->setPresetsFile((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 17: _t->setPresetsFile(); break;
        case 18: _t->savePresetsFile(); break;
        case 19: _t->onWebcamComboChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 20: _t->onWebcamResolutionComboChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 21: _t->onUseBuiltinPresets((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 22: _t->onReloadPresets(); break;
        case 23: _t->onPreviewModeChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 24: _t->onRightPanel((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 25: _t->onComboSourceChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 26: _t->onOpenImageFile(); break;
        case 27: _t->onOpenVideoFile(); break;
        case 28: _t->updateWindowTitle(); break;
        case 29: _t->onVideoFileLoop((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 30: _t->changePlayButtonAppearence((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 31: _t->onFilterThreadFinished(); break;
        case 32: _t->onCommandParametersChanged(); break;
        case 33: _t->onCommandParametersChangedFullScreen(); break;
        case 34: _t->toggleFullScreenMode(); break;
        case 35: _t->onRefreshCameraResolutions(); break;
        case 36: _t->onDetectCameras(); break;
        case 37: _t->initGUIFromCameraList((*reinterpret_cast< const QList<int>(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 38: _t->onOutputWindow((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 39: _t->onOutputWindowClosing(); break;
        case 40: _t->onAddFave(); break;
        case 41: _t->onRemoveFave(); break;
        case 42: _t->onFaveSelected((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 43: _t->onRenameFave(); break;
        default: ;
        }
    }
}

const QMetaObjectExtraData MainWindow::staticMetaObjectExtraData = {
    0,  qt_static_metacall 
};

const QMetaObject MainWindow::staticMetaObject = {
    { &QMainWindow::staticMetaObject, qt_meta_stringdata_MainWindow,
      qt_meta_data_MainWindow, &staticMetaObjectExtraData }
};

#ifdef Q_NO_DATA_RELOCATION
const QMetaObject &MainWindow::getStaticMetaObject() { return staticMetaObject; }
#endif //Q_NO_DATA_RELOCATION

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->metaObject : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return 0;
    if (!strcmp(_clname, qt_meta_stringdata_MainWindow))
        return static_cast<void*>(const_cast< MainWindow*>(this));
    if (!strcmp(_clname, "Ui::MainWindow"))
        return static_cast< Ui::MainWindow*>(const_cast< MainWindow*>(this));
    return QMainWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}
QT_END_MOC_NAMESPACE
